# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: energise.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import c37_pb2 as c37__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='energise.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0e\x65nergise.proto\x12\x06xbospb\x1a\tc37.proto\"\x7f\n\x0f\x45nergiseMessage\x12\x1a\n\x04SPBC\x18\x01 \x01(\x0b\x32\x0c.xbospb.SPBC\x12&\n\nLPBCStatus\x18\x02 \x01(\x0b\x32\x12.xbospb.LPBCStatus\x12(\n\x0bLPBCCommand\x18\x03 \x01(\x0b\x32\x13.xbospb.LPBCCommand\"\x1c\n\rEnergiseError\x12\x0b\n\x03msg\x18\x01 \x01(\t\"a\n\x04SPBC\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12%\n\rphasor_target\x18\x02 \x01(\x0b\x32\x0e.xbospb.Phasor\x12$\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x15.xbospb.EnergiseError\"\x88\x01\n\nLPBCStatus\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12$\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.xbospb.EnergiseError\x12\x1f\n\x07phasors\x18\x03 \x01(\x0b\x32\x0e.xbospb.Phasor\x12\x11\n\tsaturated\x18\x04 \x01(\x08\x12\x12\n\ndo_control\x18\x05 \x01(\x08\"V\n\x0bLPBCCommand\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12%\n\rphasor_target\x18\x02 \x01(\x0b\x32\x0e.xbospb.Phasor\x12\x12\n\ndo_control\x18\x03 \x01(\x08\x62\x06proto3')
  ,
  dependencies=[c37__pb2.DESCRIPTOR,])




_ENERGISEMESSAGE = _descriptor.Descriptor(
  name='EnergiseMessage',
  full_name='xbospb.EnergiseMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='SPBC', full_name='xbospb.EnergiseMessage.SPBC', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LPBCStatus', full_name='xbospb.EnergiseMessage.LPBCStatus', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LPBCCommand', full_name='xbospb.EnergiseMessage.LPBCCommand', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=164,
)


_ENERGISEERROR = _descriptor.Descriptor(
  name='EnergiseError',
  full_name='xbospb.EnergiseError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg', full_name='xbospb.EnergiseError.msg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=194,
)


_SPBC = _descriptor.Descriptor(
  name='SPBC',
  full_name='xbospb.SPBC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.SPBC.time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phasor_target', full_name='xbospb.SPBC.phasor_target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='xbospb.SPBC.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=293,
)


_LPBCSTATUS = _descriptor.Descriptor(
  name='LPBCStatus',
  full_name='xbospb.LPBCStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.LPBCStatus.time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='xbospb.LPBCStatus.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phasors', full_name='xbospb.LPBCStatus.phasors', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saturated', full_name='xbospb.LPBCStatus.saturated', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='do_control', full_name='xbospb.LPBCStatus.do_control', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=432,
)


_LPBCCOMMAND = _descriptor.Descriptor(
  name='LPBCCommand',
  full_name='xbospb.LPBCCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.LPBCCommand.time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phasor_target', full_name='xbospb.LPBCCommand.phasor_target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='do_control', full_name='xbospb.LPBCCommand.do_control', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=520,
)

_ENERGISEMESSAGE.fields_by_name['SPBC'].message_type = _SPBC
_ENERGISEMESSAGE.fields_by_name['LPBCStatus'].message_type = _LPBCSTATUS
_ENERGISEMESSAGE.fields_by_name['LPBCCommand'].message_type = _LPBCCOMMAND
_SPBC.fields_by_name['phasor_target'].message_type = c37__pb2._PHASOR
_SPBC.fields_by_name['error'].message_type = _ENERGISEERROR
_LPBCSTATUS.fields_by_name['error'].message_type = _ENERGISEERROR
_LPBCSTATUS.fields_by_name['phasors'].message_type = c37__pb2._PHASOR
_LPBCCOMMAND.fields_by_name['phasor_target'].message_type = c37__pb2._PHASOR
DESCRIPTOR.message_types_by_name['EnergiseMessage'] = _ENERGISEMESSAGE
DESCRIPTOR.message_types_by_name['EnergiseError'] = _ENERGISEERROR
DESCRIPTOR.message_types_by_name['SPBC'] = _SPBC
DESCRIPTOR.message_types_by_name['LPBCStatus'] = _LPBCSTATUS
DESCRIPTOR.message_types_by_name['LPBCCommand'] = _LPBCCOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EnergiseMessage = _reflection.GeneratedProtocolMessageType('EnergiseMessage', (_message.Message,), dict(
  DESCRIPTOR = _ENERGISEMESSAGE,
  __module__ = 'energise_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.EnergiseMessage)
  ))
_sym_db.RegisterMessage(EnergiseMessage)

EnergiseError = _reflection.GeneratedProtocolMessageType('EnergiseError', (_message.Message,), dict(
  DESCRIPTOR = _ENERGISEERROR,
  __module__ = 'energise_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.EnergiseError)
  ))
_sym_db.RegisterMessage(EnergiseError)

SPBC = _reflection.GeneratedProtocolMessageType('SPBC', (_message.Message,), dict(
  DESCRIPTOR = _SPBC,
  __module__ = 'energise_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.SPBC)
  ))
_sym_db.RegisterMessage(SPBC)

LPBCStatus = _reflection.GeneratedProtocolMessageType('LPBCStatus', (_message.Message,), dict(
  DESCRIPTOR = _LPBCSTATUS,
  __module__ = 'energise_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.LPBCStatus)
  ))
_sym_db.RegisterMessage(LPBCStatus)

LPBCCommand = _reflection.GeneratedProtocolMessageType('LPBCCommand', (_message.Message,), dict(
  DESCRIPTOR = _LPBCCOMMAND,
  __module__ = 'energise_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.LPBCCommand)
  ))
_sym_db.RegisterMessage(LPBCCommand)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dentmeter.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dentmeter.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0f\x64\x65ntmeter.proto\x12\x06xbospb\"B\n\x0e\x44\x65ntMeterState\x12\x0c\n\x04time\x18\x01 \x01(\x04\x12\"\n\x06phases\x18\x02 \x03(\x0b\x32\x12.xbospb.PhaseState\"\xbf\x02\n\nPhaseState\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x12\n\nannotation\x18\x0e \x01(\t\x12\x13\n\x0btrue_energy\x18\x02 \x01(\x01\x12\x17\n\x0freactive_energy\x18\x03 \x01(\x01\x12\x17\n\x0f\x61pparent_energy\x18\x04 \x01(\x01\x12\x12\n\ntrue_power\x18\x05 \x01(\x01\x12\x16\n\x0ereactive_power\x18\x06 \x01(\x01\x12\x16\n\x0e\x61pparent_power\x18\x07 \x01(\x01\x12\x17\n\x0f\x64isplacement_pf\x18\x08 \x01(\x01\x12\x13\n\x0b\x61pparent_pf\x18\t \x01(\x01\x12\x0f\n\x07\x63urrent\x18\n \x01(\x01\x12\x16\n\x0eline_frequency\x18\x0b \x01(\x01\x12\r\n\x05volts\x18\x0c \x01(\x01\x12\x1d\n\x15phase_neutral_voltage\x18\r \x01(\x01\x62\x06proto3')
)




_DENTMETERSTATE = _descriptor.Descriptor(
  name='DentMeterState',
  full_name='xbospb.DentMeterState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.DentMeterState.time', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phases', full_name='xbospb.DentMeterState.phases', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=93,
)


_PHASESTATE = _descriptor.Descriptor(
  name='PhaseState',
  full_name='xbospb.PhaseState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='xbospb.PhaseState.phase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation', full_name='xbospb.PhaseState.annotation', index=1,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='true_energy', full_name='xbospb.PhaseState.true_energy', index=2,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reactive_energy', full_name='xbospb.PhaseState.reactive_energy', index=3,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apparent_energy', full_name='xbospb.PhaseState.apparent_energy', index=4,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='true_power', full_name='xbospb.PhaseState.true_power', index=5,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reactive_power', full_name='xbospb.PhaseState.reactive_power', index=6,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apparent_power', full_name='xbospb.PhaseState.apparent_power', index=7,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displacement_pf', full_name='xbospb.PhaseState.displacement_pf', index=8,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apparent_pf', full_name='xbospb.PhaseState.apparent_pf', index=9,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current', full_name='xbospb.PhaseState.current', index=10,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_frequency', full_name='xbospb.PhaseState.line_frequency', index=11,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volts', full_name='xbospb.PhaseState.volts', index=12,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase_neutral_voltage', full_name='xbospb.PhaseState.phase_neutral_voltage', index=13,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=415,
)

_DENTMETERSTATE.fields_by_name['phases'].message_type = _PHASESTATE
DESCRIPTOR.message_types_by_name['DentMeterState'] = _DENTMETERSTATE
DESCRIPTOR.message_types_by_name['PhaseState'] = _PHASESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DentMeterState = _reflection.GeneratedProtocolMessageType('DentMeterState', (_message.Message,), dict(
  DESCRIPTOR = _DENTMETERSTATE,
  __module__ = 'dentmeter_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.DentMeterState)
  ))
_sym_db.RegisterMessage(DentMeterState)

PhaseState = _reflection.GeneratedProtocolMessageType('PhaseState', (_message.Message,), dict(
  DESCRIPTOR = _PHASESTATE,
  __module__ = 'dentmeter_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.PhaseState)
  ))
_sym_db.RegisterMessage(PhaseState)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: brick.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='brick.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0b\x62rick.proto\x12\x06xbospb\x1a google/protobuf/descriptor.proto\"\'\n\x03URI\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"c\n\x06Triple\x12\x1c\n\x07subject\x18\x01 \x01(\x0b\x32\x0b.xbospb.URI\x12\x1e\n\tpredicate\x18\x02 \x01(\x0b\x32\x0b.xbospb.URI\x12\x1b\n\x06object\x18\x03 \x01(\x0b\x32\x0b.xbospb.URI:H\n\x11\x62rick_equip_class\x12\x1f.google.protobuf.MessageOptions\x18\x90N \x01(\x0b\x32\x0b.xbospb.URI:G\n\x11\x62rick_point_class\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x0b\x32\x0b.xbospb.URIb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


BRICK_EQUIP_CLASS_FIELD_NUMBER = 10000
brick_equip_class = _descriptor.FieldDescriptor(
  name='brick_equip_class', full_name='xbospb.brick_equip_class', index=0,
  number=10000, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
BRICK_POINT_CLASS_FIELD_NUMBER = 50000
brick_point_class = _descriptor.FieldDescriptor(
  name='brick_point_class', full_name='xbospb.brick_point_class', index=1,
  number=50000, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_URI = _descriptor.Descriptor(
  name='URI',
  full_name='xbospb.URI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='xbospb.URI.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='xbospb.URI.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=96,
)


_TRIPLE = _descriptor.Descriptor(
  name='Triple',
  full_name='xbospb.Triple',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='xbospb.Triple.subject', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predicate', full_name='xbospb.Triple.predicate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='xbospb.Triple.object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=197,
)

_TRIPLE.fields_by_name['subject'].message_type = _URI
_TRIPLE.fields_by_name['predicate'].message_type = _URI
_TRIPLE.fields_by_name['object'].message_type = _URI
DESCRIPTOR.message_types_by_name['URI'] = _URI
DESCRIPTOR.message_types_by_name['Triple'] = _TRIPLE
DESCRIPTOR.extensions_by_name['brick_equip_class'] = brick_equip_class
DESCRIPTOR.extensions_by_name['brick_point_class'] = brick_point_class
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

URI = _reflection.GeneratedProtocolMessageType('URI', (_message.Message,), dict(
  DESCRIPTOR = _URI,
  __module__ = 'brick_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.URI)
  ))
_sym_db.RegisterMessage(URI)

Triple = _reflection.GeneratedProtocolMessageType('Triple', (_message.Message,), dict(
  DESCRIPTOR = _TRIPLE,
  __module__ = 'brick_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Triple)
  ))
_sym_db.RegisterMessage(Triple)

brick_equip_class.message_type = _URI
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(brick_equip_class)
brick_point_class.message_type = _URI
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(brick_point_class)

# @@protoc_insertion_point(module_scope)



class PyXBOSError(Exception):
    """Base class for exceptions in pyxbos"""
    pass

class ConfigMissingError(PyXBOSError):
    """Exception raised for errors in the input.

    Attributes:
        expected -- expected key
    """

    def __init__(self, expected, extra=""):
        self.expected = expected
        self.message = "Expected key \"{0}\" in config ({1})".format(expected, extra)




# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: energize.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import nullabletypes_pb2 as nullabletypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='energize.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0e\x65nergize.proto\x12\x06xbospb\x1a\x13nullabletypes.proto\"\x0b\n\tSPBCInput\"*\n\x06Phasor\x12\x11\n\tmagnitude\x18\x01 \x01(\x01\x12\r\n\x05\x61ngle\x18\x02 \x01(\x01\"6\n\x06Target\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x06target\x18\x02 \x01(\x0b\x32\x0e.xbospb.Phasor\"4\n\nSPBCOutput\x12&\n\x0ephasor_targets\x18\x01 \x03(\x0b\x32\x0e.xbospb.Targetb\x06proto3')
  ,
  dependencies=[nullabletypes__pb2.DESCRIPTOR,])




_SPBCINPUT = _descriptor.Descriptor(
  name='SPBCInput',
  full_name='xbospb.SPBCInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=58,
)


_PHASOR = _descriptor.Descriptor(
  name='Phasor',
  full_name='xbospb.Phasor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='magnitude', full_name='xbospb.Phasor.magnitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle', full_name='xbospb.Phasor.angle', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=102,
)


_TARGET = _descriptor.Descriptor(
  name='Target',
  full_name='xbospb.Target',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xbospb.Target.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='xbospb.Target.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=158,
)


_SPBCOUTPUT = _descriptor.Descriptor(
  name='SPBCOutput',
  full_name='xbospb.SPBCOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phasor_targets', full_name='xbospb.SPBCOutput.phasor_targets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=212,
)

_TARGET.fields_by_name['target'].message_type = _PHASOR
_SPBCOUTPUT.fields_by_name['phasor_targets'].message_type = _TARGET
DESCRIPTOR.message_types_by_name['SPBCInput'] = _SPBCINPUT
DESCRIPTOR.message_types_by_name['Phasor'] = _PHASOR
DESCRIPTOR.message_types_by_name['Target'] = _TARGET
DESCRIPTOR.message_types_by_name['SPBCOutput'] = _SPBCOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SPBCInput = _reflection.GeneratedProtocolMessageType('SPBCInput', (_message.Message,), dict(
  DESCRIPTOR = _SPBCINPUT,
  __module__ = 'energize_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.SPBCInput)
  ))
_sym_db.RegisterMessage(SPBCInput)

Phasor = _reflection.GeneratedProtocolMessageType('Phasor', (_message.Message,), dict(
  DESCRIPTOR = _PHASOR,
  __module__ = 'energize_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Phasor)
  ))
_sym_db.RegisterMessage(Phasor)

Target = _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), dict(
  DESCRIPTOR = _TARGET,
  __module__ = 'energize_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Target)
  ))
_sym_db.RegisterMessage(Target)

SPBCOutput = _reflection.GeneratedProtocolMessageType('SPBCOutput', (_message.Message,), dict(
  DESCRIPTOR = _SPBCOUTPUT,
  __module__ = 'energize_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.SPBCOutput)
  ))
_sym_db.RegisterMessage(SPBCOutput)


# @@protoc_insertion_point(module_scope)



from pyxbos.process import XBOSProcess, b64decode, b64encode, schedule, run_loop
from pyxbos.xbos_pb2 import XBOS
from pyxbos.energise_pb2 import EnergiseMessage, LPBCStatus, LPBCCommand, SPBC, EnergiseError
from pyxbos.c37_pb2 import Phasor
from datetime import datetime
from collections import deque

class SPBCProcess(XBOSProcess):
    def __init__(self, cfg):
        super().__init__(cfg)
        if 'namespace' not in cfg:
            raise ConfigMissingError('namespace')
        elif 'name' not in cfg:
            raise ConfigMissingError('name')
        self.namespace = b64decode(cfg['namespace'])
        self._log.info(f"initialized SPBC: {cfg}")
        self.name = cfg['name']

        self.lpbcs = {}
        schedule(self.subscribe_extract(self.namespace, "lpbc/*", ".EnergiseMessage.LPBCStatus", self._lpbccb))

    def _lpbccb(self, resp):
        self.lpbcs[resp.uri] = resp

    async def broadcast_target(self, p, q):
        self._log.info(f"SPBC announcing p {p} q {q}")
        await self.publish(self.namespace, f"spbc/{self.name}", XBOS(
            EnergiseMessage = EnergiseMessage(
            SPBC=SPBC(
                time=int(datetime.utcnow().timestamp()*1e9),
                phasor_target=Phasor(P=p, Q=q)
                )
            )))


class LPBCProcess(XBOSProcess):
    def __init__(self, cfg):
        super().__init__(cfg)
        if 'namespace' not in cfg:
            raise ConfigMissingError('namespace')
        self.namespace = b64decode(cfg['namespace'])
        if 'upmu' not in cfg:
            raise ConfigMissingError('upmu')
        if 'name' not in cfg:
            raise ConfigMissingError('name')
        if 'spbc' not in cfg:
            raise ConfigMissingError('spbc')
        if 'rate' not in cfg:
            raise ConfigMissingError('rate')
        self.upmu = cfg['upmu']
        self.name = cfg['name']
        self.spbc = cfg['spbc']
        self._rate = int(cfg['rate'])
        self.last_upmu_reading = None
        self.last_spbc_command = None
        self.control_on = False

        schedule(self.subscribe_extract(self.namespace, f"upmu/{self.upmu}", ".C37DataFrame", self._upmucb))
        schedule(self.subscribe_extract(self.namespace, f"spbc/{self.spbc}", ".EnergiseMessage.SPBC", self._spbccb))
	
        schedule(self.call_periodic(self._rate, self._trigger, runfirst=False))

        self._log.info(f"initialized LPBC: {cfg}")

    def _upmucb(self, resp):
        self.last_upmu_reading = resp
    def _spbccb(self, resp):
        self.last_spbc_command = resp

    async def _trigger(self):
        try:
            if self.last_upmu_reading is None or len(self.last_upmu_reading.values) == 0:
                self._log.warning(f"LPBC {self.name} has not received a upmu reading")
                return
            if self.last_spbc_command is None or len(self.last_spbc_command.values) == 0:
                self._log.warning(f"LPBC {self.name} has not received an SPBC command")
                return
            c37_frame = self.last_upmu_reading.values[-1] # most recent
            spbc_cmd = self.last_spbc_command.values[-1] # most recent
            targets = spbc_cmd['phasorTarget']
            await self.do_trigger(c37_frame, targets['P'], targets['Q'])
        except IndexError:
            return # no upmu readings

    async def do_trigger(self, c37_frame, p_target, q_target):
        self._log.info(f"""LPBC {self.name} received call at {datetime.now()}:
    C37 data frame: {c37_frame}
    SPBC targets: P: {p_target} Q: {q_target}
    Enable control?: {self.control_on}
        """)
        error, mp, mq, sat = self.step(c37_frame, p_target, q_target)

        msg = XBOS(
                EnergiseMessage=EnergiseMessage(
                    LPBCStatus=LPBCStatus(
                        time=int(datetime.utcnow().timestamp()*1e9),
                        phasors=Phasor(P=mp, Q=mq),
                        saturated=sat,
                        do_control=self.control_on,
                    )
                ))
        await self.publish(self.namespace, f"lpbc/{self.name}", msg)



"""
Simple wrapper for a control process
"""

import asyncio
import xxhash
from datetime import datetime
import logging
import base64
import os
import jq
import uuid
from aiogrpc import insecure_channel
from google.protobuf.json_format import MessageToDict
from pyxbos.exceptions import *
from . import xbos_pb2
from .eapi_pb2 import *
from .wavemq_pb2 import *
from .wavemq_pb2_grpc import *

class XBOSProcess:
    """
    Base class wrapping interaction with WAVE, WAVEMQ
    """
    def __init__(self, cfg=None):
        """
        Config takes the following keys:

        wavemq (default localhost:4516): address of wavemq site router
        waved (default localhost:410): address of waved agent
        entity (default $WAVE_DEFAULT_ENTITY): filepath to entity file of this process
        expiry (default 2 minutes): time we can remain disconnected from wavemq before undelivered
              messages in our subscriptions are dropped
        """
        self._log = logging.getLogger(__name__)
        if cfg is None:
            cfg = {}

        self._log.info("Reading config {0}".format(str(cfg)))

        # check defaults
        if 'wavemq' not in cfg:
            cfg['wavemq'] = 'localhost:4516'
        if 'waved' not in cfg:
            cfg['waved'] = 'localhost:410'
        if 'entity' not in cfg:
            if 'WAVE_DEFAULT_ENTITY' in os.environ:
                cfg['entity'] = os.environ['WAVE_DEFAULT_ENTITY']
            else:
                raise ConfigMissingError('entity', extra="And no WAVE_DEFAULT_ENTITY in environment")
        if 'expiry' not in cfg:
            cfg['expiry'] = 10 # default to 10 second expiry

        self._cfg = cfg

        # connect to the wavemq agent
        self._log.info("Connecting to wavemq agent at {0}".format(cfg['wavemq']))
        self._connect()
        self._log.info("Connected to wavemq")

        # load the wave entity
        self._log.info("Loading wave entity {0}".format(cfg['entity']))
        self._ent = open(self._cfg['entity'],'rb').read()
        self._perspective = Perspective(
            entitySecret=EntitySecret(DER=self._ent),
        )
        self._subscription_expiry = cfg['expiry']

        # associate (ns, uri) => identifier
        self._subscription_ids = {}

    def _get_identifier(self, namespace, resource):
        """
        Assumes namespace is b64 encoded
        """
        h = xxhash.xxh32()
        h.update(self._ent)
        h.update(namespace)
        h.update(resource)
        identifier = b64encode(h.digest())
        return identifier

#        key = (namespace, resource)
#        while self._subscription_ids.get(key) 
#        if self._subscription_ids.get(key) is None:
#            self._subscription_ids[key] = identifier
#        else:
#            h.
#        return self._subscription_ids[key]

    def _connect(self):
        # connect to wavemq agent
        wavemq_channel = insecure_channel(self._cfg['wavemq'])
        self._cl = WAVEMQStub(wavemq_channel)

    async def subscribe_msg(self, namespace, resource, callback):
        """
        callback takes mqpb_pb.SubscriptionMessage as an argument
        """
        ns = ensure_b64decode(namespace)
        async for msg in self._cl.Subscribe(SubscribeParams(
                perspective=self._perspective,
                namespace=ns,
                uri=resource,
                identifier=self._get_identifier(namespace, resource),
                expiry=self._subscription_expiry,
            )
            ):
            callback(msg)

    async def subscribe_extract(self, namespace, resource, path, callback):
        """
        extracts the submessage at the given path
        callback returns a Response object:
        - uri
        - namespace (base64)
        - sent timestamp
        - submessage (list)
        """
        def cb(msg):
            uri = msg.message.tbs.uri
            namespace = ensure_b64encode(msg.message.tbs.namespace)
            sent_timestamp = msg.message.timestamps
            if len(sent_timestamp) == 0:
                sent_timestamp = datetime.now()
            else:
                sent_timestamp = datetime.utcfromtimestamp(sent_timestamp[0])
            values = []
            for po in msg.message.tbs.payload:
                x = xbos_pb2.XBOS.FromString(po.content)
                x = MessageToDict(x)
                values.append(jq.jq(path).transform(x))
            callback(Response(namespace, uri, sent_timestamp, values))
        await self.subscribe_msg(namespace, resource, cb)

    async def publish(self, namespace, resource, *msgs):
        """publishes msgs in list as payload objects"""
        pos = []
        for msg in msgs:
            pos.append(PayloadObject(
                schema = "xbosproto/XBOS",
                content = msg.SerializeToString(),
                ))
        namespace = ensure_b64decode(namespace)
        try:
            x = await self._cl.Publish(PublishParams(
                perspective=self._perspective,
                namespace=namespace,
                uri = resource,
                content = pos,
                ))
            if not x:
                self._log.error("Error publishing: {0}".format(x))
        except Exception as e:
            self._log.error("Error publishing: {0}".format(e))


    async def call_periodic(self, seconds, cb, *args, runfirst=True):
        """
        Run asynchronous function every n seconds. If runfirst is true, we run
        the function once before starting the timer
        """
        if runfirst:
            await cb(*args)
        while True:
            await asyncio.sleep(seconds)
            await cb(*args)

class Response():
    def __init__(self, ns, uri, ts, values):
        self.ns = ns
        self.uri = uri
        self.ts = ts
        self.values = values

    def __repr__(self):
        return f"Response<({self.ns}, {self.uri}, {self.ts}, {self.values}"

def b64decode(e):
    return base64.b64decode(e, altchars=bytes('-_', 'utf8'))
def ensure_b64decode(e):
    return e if isinstance(e, bytes) else b64decode(e)

def ensure_b64encode(e):
    return b64encode(e) if isinstance(e, bytes) else e
def b64encode(e):
    return base64.b64encode(e, altchars=bytes('-_', 'utf8'))


def schedule(f):
    """
    Runs task asynchronously (subscribe, publish)
    """
    asyncio.ensure_future(f)

def run_loop():
    """
    Block forever, running async tasks
    """
    loop = asyncio.get_event_loop()
    loop.run_forever()
    loop.close()




# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: iot.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import nullabletypes_pb2 as nullabletypes__pb2
from . import weather_station_pb2 as weather__station__pb2
from . import brick_pb2 as brick__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='iot.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\tiot.proto\x12\x06xbospb\x1a\x13nullabletypes.proto\x1a\x15weather_station.proto\x1a\x0b\x62rick.proto\"\x14\n\x05\x45rror\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\xca\x02\n\x12XBOSIoTDeviceState\x12\x0c\n\x04time\x18\x01 \x01(\x04\x12\x11\n\trequestid\x18\x02 \x01(\x03\x12\x1c\n\x05\x65rror\x18\x03 \x01(\x0b\x32\r.xbospb.Error\x12&\n\nthermostat\x18\x04 \x01(\x0b\x32\x12.xbospb.Thermostat\x12\x1c\n\x05meter\x18\x05 \x01(\x0b\x32\r.xbospb.Meter\x12\x1c\n\x05light\x18\x06 \x01(\x0b\x32\r.xbospb.Light\x12\x1a\n\x04\x65vse\x18\x07 \x01(\x0b\x32\x0c.xbospb.EVSE\x12/\n\x0fweather_station\x18\x08 \x01(\x0b\x32\x16.xbospb.WeatherStation\x12\x44\n\x1aweather_station_prediction\x18\t \x01(\x0b\x32 .xbospb.WeatherStationPrediction\"\xb9\x01\n\x16XBOSIoTDeviceActuation\x12\x0c\n\x04time\x18\x01 \x01(\x04\x12\x11\n\trequestid\x18\x02 \x01(\x03\x12&\n\nthermostat\x18\x03 \x01(\x0b\x32\x12.xbospb.Thermostat\x12\x1c\n\x05meter\x18\x04 \x01(\x0b\x32\r.xbospb.Meter\x12\x1c\n\x05light\x18\x05 \x01(\x0b\x32\r.xbospb.Light\x12\x1a\n\x04\x65vse\x18\x06 \x01(\x0b\x32\x0c.xbospb.EVSE\"?\n\x0eXBOSIoTContext\x12\x0c\n\x04time\x18\x01 \x01(\x04\x12\x1f\n\x07\x63ontext\x18\x02 \x03(\x0b\x32\x0e.xbospb.Triple\"\x8d\t\n\nThermostat\x12n\n\x0btemperature\x18\x01 \x01(\x0b\x32\x0e.xbospb.DoubleBI\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x14\x12\x12Temperature_Sensor\x12q\n\x11relative_humidity\x18\x02 \x01(\x0b\x32\x0e.xbospb.DoubleBF\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x11\x12\x0fHumidity_Sensor\x12g\n\x08override\x18\x03 \x01(\x0b\x32\x0c.xbospb.BoolBG\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x12\x12\x10Override_Command\x12\x62\n\tfan_state\x18\x04 \x01(\x0b\x32\x0c.xbospb.BoolBA\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x0c\x12\nFan_Status\x12\x65\n\x08\x66\x61n_mode\x18\x05 \x01(\x0b\x32\x0f.xbospb.FanModeBB\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\r\x12\x0b\x46\x61n_Command\x12\x63\n\x04mode\x18\x06 \x01(\x0b\x32\x10.xbospb.HVACModeBC\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x0e\x12\x0cMode_Command\x12j\n\x05state\x18\x07 \x01(\x0b\x32\x11.xbospb.HVACStateBH\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x13\x12\x11Thermostat_Status\x12*\n\x13\x65nabled_heat_stages\x18\x08 \x01(\x0b\x32\r.xbospb.Int32\x12*\n\x13\x65nabled_cool_stages\x18\t \x01(\x0b\x32\r.xbospb.Int32\x12}\n\x10heating_setpoint\x18\n \x01(\x0b\x32\x0e.xbospb.DoubleBS\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1e\x12\x1cHeating_Temperature_Setpoint\x12}\n\x10\x63ooling_setpoint\x18\x0b \x01(\x0b\x32\x0e.xbospb.DoubleBS\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1e\x12\x1c\x43ooling_Temperature_Setpoint:A\x82\xf1\x04-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xf1\x04\x0c\x12\nThermostat\"\xa9\x01\n\x12ThermostatSchedule\x12@\n\x0bscheduleMap\x18\x01 \x03(\x0b\x32+.xbospb.ThermostatSchedule.ScheduleMapEntry\x1aQ\n\x10ScheduleMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.xbospb.ThermostatScheduleDay:\x02\x38\x01\"H\n\x15ThermostatScheduleDay\x12/\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x1f.xbospb.ThermostatScheduleBlock\"\x9b\x01\n\x17ThermostatScheduleBlock\x12(\n\x10heating_setpoint\x18\x01 \x01(\x0b\x32\x0e.xbospb.Double\x12(\n\x10\x63ooling_setpoint\x18\x02 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1e\n\x04mode\x18\x03 \x01(\x0b\x32\x10.xbospb.HVACMode\x12\x0c\n\x04time\x18\x04 \x01(\t\"\xe3\x01\n\x13\x44\x65mandResponseEvent\x12 \n\tevent_end\x18\x01 \x01(\x0b\x32\r.xbospb.Int64\x12\"\n\x0b\x65vent_start\x18\x02 \x01(\x0b\x32\r.xbospb.Int64\x12\x33\n\nevent_type\x18\x03 \x01(\x0e\x32\x1f.xbospb.DemandResponseEventType\x12\x34\n\tdr_status\x18\x04 \x01(\x0e\x32!.xbospb.DemandResponseEventStatus\x12\x1b\n\x04time\x18\x05 \x01(\x0b\x32\r.xbospb.Int64\"\x80\x0c\n\x05Meter\x12\x62\n\x05power\x18\x01 \x01(\x0b\x32\x0e.xbospb.DoubleBC\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x0e\x12\x0cPower_Sensor\x12\x66\n\x07voltage\x18\x02 \x01(\x0b\x32\x0e.xbospb.DoubleBE\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x10\x12\x0eVoltage_Sensor\x12t\n\x0e\x61pparent_power\x18\x03 \x01(\x0b\x32\x0e.xbospb.DoubleBL\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x17\x12\x15\x41pparent_Power_Sensor\x12\x64\n\x06\x65nergy\x18\x04 \x01(\x0b\x32\x0e.xbospb.DoubleBD\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x0f\x12\rEnergy_Sensor\x12t\n\x0ereactive_power\x18\x05 \x01(\x0b\x32\x0e.xbospb.DoubleBL\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x17\x12\x15Reactive_Power_Sensor\x12\x66\n\x07\x63urrent\x18\x06 \x01(\x0b\x32\x0e.xbospb.DoubleBE\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x10\x12\x0e\x43urrent_Sensor\x12\x64\n\x06\x64\x65mand\x18\x07 \x01(\x0b\x32\x0e.xbospb.DoubleBD\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x0f\x12\rDemand_Sensor\x12n\n\x0bwater_total\x18\x08 \x01(\x0b\x32\x0e.xbospb.DoubleBI\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x14\x12\x12Water_Total_Sensor\x12l\n\nwater_rate\x18\t \x01(\x0b\x32\x0e.xbospb.DoubleBH\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x13\x12\x11Water_Rate_Sensor\x12~\n\x13water_instantaneous\x18\n \x01(\x0b\x32\x0e.xbospb.DoubleBQ\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1c\x12\x1aWater_Instantaneous_Sensor\x12t\n\x0e\x63ondense_total\x18\x0b \x01(\x0b\x32\x0e.xbospb.DoubleBL\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x17\x12\x15\x43ondense_Total_Sensor\x12r\n\rcondense_rate\x18\x0c \x01(\x0b\x32\x0e.xbospb.DoubleBK\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x16\x12\x14\x43ondense_Rate_Sensor\x12\x84\x01\n\x16\x63ondense_instantaneous\x18\r \x01(\x0b\x32\x0e.xbospb.DoubleBT\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1f\x12\x1d\x43ondense_Instantaneous_Sensor:<\x82\xf1\x04-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xf1\x04\x07\x12\x05Meter\"\x9a\x02\n\x05Light\x12\x62\n\x05state\x18\x01 \x01(\x0b\x32\x0c.xbospb.BoolBE\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x10\x12\x0eLighting_State\x12k\n\nbrightness\x18\x02 \x01(\x0b\x32\r.xbospb.Int64BH\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x13\x12\x11Luminance_Command:@\x82\xf1\x04-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xf1\x04\x0b\x12\tLuminaire\"\xb7\x01\n\x04\x45VSE\x12%\n\rcurrent_limit\x18\x01 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1f\n\x07\x63urrent\x18\x02 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1f\n\x07voltage\x18\x03 \x01(\x0b\x32\x0e.xbospb.Double\x12)\n\x12\x63harging_time_left\x18\x04 \x01(\x0b\x32\r.xbospb.Int32\x12\x1b\n\x05state\x18\x05 \x01(\x0b\x32\x0c.xbospb.Bool*\xba\x01\n\x19\x44\x65mandResponseEventStatus\x12*\n&DemandResponseEventStatusNotConfigured\x10\x00\x12%\n!DemandResponseEventStatusUnusable\x10\x01\x12%\n!DemandResponseEventStatusInactive\x10\x02\x12#\n\x1f\x44\x65mandResponseEventStatusActive\x10\x03*\xca\x01\n\x17\x44\x65mandResponseEventType\x12\"\n\x1e\x44\x65mandResponseEventTypeNoEvent\x10\x00\x12!\n\x1d\x44\x65mandResponseEventTypeNormal\x10\x01\x12#\n\x1f\x44\x65mandResponseEventTypeModerate\x10\x02\x12\x1f\n\x1b\x44\x65mandResponseEventTypeHigh\x10\x03\x12\"\n\x1e\x44\x65mandResponseEventTypeSpecial\x10\x04\x62\x06proto3')
  ,
  dependencies=[nullabletypes__pb2.DESCRIPTOR,weather__station__pb2.DESCRIPTOR,brick__pb2.DESCRIPTOR,])

_DEMANDRESPONSEEVENTSTATUS = _descriptor.EnumDescriptor(
  name='DemandResponseEventStatus',
  full_name='xbospb.DemandResponseEventStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DemandResponseEventStatusNotConfigured', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DemandResponseEventStatusUnusable', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DemandResponseEventStatusInactive', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DemandResponseEventStatusActive', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4499,
  serialized_end=4685,
)
_sym_db.RegisterEnumDescriptor(_DEMANDRESPONSEEVENTSTATUS)

DemandResponseEventStatus = enum_type_wrapper.EnumTypeWrapper(_DEMANDRESPONSEEVENTSTATUS)
_DEMANDRESPONSEEVENTTYPE = _descriptor.EnumDescriptor(
  name='DemandResponseEventType',
  full_name='xbospb.DemandResponseEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DemandResponseEventTypeNoEvent', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DemandResponseEventTypeNormal', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DemandResponseEventTypeModerate', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DemandResponseEventTypeHigh', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DemandResponseEventTypeSpecial', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4688,
  serialized_end=4890,
)
_sym_db.RegisterEnumDescriptor(_DEMANDRESPONSEEVENTTYPE)

DemandResponseEventType = enum_type_wrapper.EnumTypeWrapper(_DEMANDRESPONSEEVENTTYPE)
DemandResponseEventStatusNotConfigured = 0
DemandResponseEventStatusUnusable = 1
DemandResponseEventStatusInactive = 2
DemandResponseEventStatusActive = 3
DemandResponseEventTypeNoEvent = 0
DemandResponseEventTypeNormal = 1
DemandResponseEventTypeModerate = 2
DemandResponseEventTypeHigh = 3
DemandResponseEventTypeSpecial = 4



_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='xbospb.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg', full_name='xbospb.Error.msg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=98,
)


_XBOSIOTDEVICESTATE = _descriptor.Descriptor(
  name='XBOSIoTDeviceState',
  full_name='xbospb.XBOSIoTDeviceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.XBOSIoTDeviceState.time', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requestid', full_name='xbospb.XBOSIoTDeviceState.requestid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='xbospb.XBOSIoTDeviceState.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thermostat', full_name='xbospb.XBOSIoTDeviceState.thermostat', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meter', full_name='xbospb.XBOSIoTDeviceState.meter', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light', full_name='xbospb.XBOSIoTDeviceState.light', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evse', full_name='xbospb.XBOSIoTDeviceState.evse', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weather_station', full_name='xbospb.XBOSIoTDeviceState.weather_station', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weather_station_prediction', full_name='xbospb.XBOSIoTDeviceState.weather_station_prediction', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=431,
)


_XBOSIOTDEVICEACTUATION = _descriptor.Descriptor(
  name='XBOSIoTDeviceActuation',
  full_name='xbospb.XBOSIoTDeviceActuation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.XBOSIoTDeviceActuation.time', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requestid', full_name='xbospb.XBOSIoTDeviceActuation.requestid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thermostat', full_name='xbospb.XBOSIoTDeviceActuation.thermostat', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meter', full_name='xbospb.XBOSIoTDeviceActuation.meter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light', full_name='xbospb.XBOSIoTDeviceActuation.light', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evse', full_name='xbospb.XBOSIoTDeviceActuation.evse', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=619,
)


_XBOSIOTCONTEXT = _descriptor.Descriptor(
  name='XBOSIoTContext',
  full_name='xbospb.XBOSIoTContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.XBOSIoTContext.time', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='xbospb.XBOSIoTContext.context', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=684,
)


_THERMOSTAT = _descriptor.Descriptor(
  name='Thermostat',
  full_name='xbospb.Thermostat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='temperature', full_name='xbospb.Thermostat.temperature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\024\022\022Temperature_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relative_humidity', full_name='xbospb.Thermostat.relative_humidity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\021\022\017Humidity_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override', full_name='xbospb.Thermostat.override', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\022\022\020Override_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fan_state', full_name='xbospb.Thermostat.fan_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\014\022\nFan_Status'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fan_mode', full_name='xbospb.Thermostat.fan_mode', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\r\022\013Fan_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='xbospb.Thermostat.mode', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\016\022\014Mode_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='xbospb.Thermostat.state', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\023\022\021Thermostat_Status'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled_heat_stages', full_name='xbospb.Thermostat.enabled_heat_stages', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled_cool_stages', full_name='xbospb.Thermostat.enabled_cool_stages', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heating_setpoint', full_name='xbospb.Thermostat.heating_setpoint', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\036\022\034Heating_Temperature_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooling_setpoint', full_name='xbospb.Thermostat.cooling_setpoint', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\036\022\034Cooling_Temperature_Setpoint'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\202\361\004-\n+https://brickschema.org/schema/1.0.3/Brick#\202\361\004\014\022\nThermostat'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=1852,
)


_THERMOSTATSCHEDULE_SCHEDULEMAPENTRY = _descriptor.Descriptor(
  name='ScheduleMapEntry',
  full_name='xbospb.ThermostatSchedule.ScheduleMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='xbospb.ThermostatSchedule.ScheduleMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='xbospb.ThermostatSchedule.ScheduleMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1943,
  serialized_end=2024,
)

_THERMOSTATSCHEDULE = _descriptor.Descriptor(
  name='ThermostatSchedule',
  full_name='xbospb.ThermostatSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduleMap', full_name='xbospb.ThermostatSchedule.scheduleMap', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_THERMOSTATSCHEDULE_SCHEDULEMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1855,
  serialized_end=2024,
)


_THERMOSTATSCHEDULEDAY = _descriptor.Descriptor(
  name='ThermostatScheduleDay',
  full_name='xbospb.ThermostatScheduleDay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='xbospb.ThermostatScheduleDay.blocks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2026,
  serialized_end=2098,
)


_THERMOSTATSCHEDULEBLOCK = _descriptor.Descriptor(
  name='ThermostatScheduleBlock',
  full_name='xbospb.ThermostatScheduleBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heating_setpoint', full_name='xbospb.ThermostatScheduleBlock.heating_setpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooling_setpoint', full_name='xbospb.ThermostatScheduleBlock.cooling_setpoint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='xbospb.ThermostatScheduleBlock.mode', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.ThermostatScheduleBlock.time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2101,
  serialized_end=2256,
)


_DEMANDRESPONSEEVENT = _descriptor.Descriptor(
  name='DemandResponseEvent',
  full_name='xbospb.DemandResponseEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_end', full_name='xbospb.DemandResponseEvent.event_end', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_start', full_name='xbospb.DemandResponseEvent.event_start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='xbospb.DemandResponseEvent.event_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dr_status', full_name='xbospb.DemandResponseEvent.dr_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.DemandResponseEvent.time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2259,
  serialized_end=2486,
)


_METER = _descriptor.Descriptor(
  name='Meter',
  full_name='xbospb.Meter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='power', full_name='xbospb.Meter.power', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\016\022\014Power_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voltage', full_name='xbospb.Meter.voltage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\020\022\016Voltage_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apparent_power', full_name='xbospb.Meter.apparent_power', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\027\022\025Apparent_Power_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy', full_name='xbospb.Meter.energy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\017\022\rEnergy_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reactive_power', full_name='xbospb.Meter.reactive_power', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\027\022\025Reactive_Power_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current', full_name='xbospb.Meter.current', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\020\022\016Current_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='demand', full_name='xbospb.Meter.demand', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\017\022\rDemand_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='water_total', full_name='xbospb.Meter.water_total', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\024\022\022Water_Total_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='water_rate', full_name='xbospb.Meter.water_rate', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\023\022\021Water_Rate_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='water_instantaneous', full_name='xbospb.Meter.water_instantaneous', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\034\022\032Water_Instantaneous_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condense_total', full_name='xbospb.Meter.condense_total', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\027\022\025Condense_Total_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condense_rate', full_name='xbospb.Meter.condense_rate', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\026\022\024Condense_Rate_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condense_instantaneous', full_name='xbospb.Meter.condense_instantaneous', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\037\022\035Condense_Instantaneous_Sensor'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\202\361\004-\n+https://brickschema.org/schema/1.0.3/Brick#\202\361\004\007\022\005Meter'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2489,
  serialized_end=4025,
)


_LIGHT = _descriptor.Descriptor(
  name='Light',
  full_name='xbospb.Light',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='xbospb.Light.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\020\022\016Lighting_State'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='brightness', full_name='xbospb.Light.brightness', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\023\022\021Luminance_Command'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\202\361\004-\n+https://brickschema.org/schema/1.0.3/Brick#\202\361\004\013\022\tLuminaire'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4028,
  serialized_end=4310,
)


_EVSE = _descriptor.Descriptor(
  name='EVSE',
  full_name='xbospb.EVSE',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_limit', full_name='xbospb.EVSE.current_limit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current', full_name='xbospb.EVSE.current', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voltage', full_name='xbospb.EVSE.voltage', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charging_time_left', full_name='xbospb.EVSE.charging_time_left', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='xbospb.EVSE.state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4313,
  serialized_end=4496,
)

_XBOSIOTDEVICESTATE.fields_by_name['error'].message_type = _ERROR
_XBOSIOTDEVICESTATE.fields_by_name['thermostat'].message_type = _THERMOSTAT
_XBOSIOTDEVICESTATE.fields_by_name['meter'].message_type = _METER
_XBOSIOTDEVICESTATE.fields_by_name['light'].message_type = _LIGHT
_XBOSIOTDEVICESTATE.fields_by_name['evse'].message_type = _EVSE
_XBOSIOTDEVICESTATE.fields_by_name['weather_station'].message_type = weather__station__pb2._WEATHERSTATION
_XBOSIOTDEVICESTATE.fields_by_name['weather_station_prediction'].message_type = weather__station__pb2._WEATHERSTATIONPREDICTION
_XBOSIOTDEVICEACTUATION.fields_by_name['thermostat'].message_type = _THERMOSTAT
_XBOSIOTDEVICEACTUATION.fields_by_name['meter'].message_type = _METER
_XBOSIOTDEVICEACTUATION.fields_by_name['light'].message_type = _LIGHT
_XBOSIOTDEVICEACTUATION.fields_by_name['evse'].message_type = _EVSE
_XBOSIOTCONTEXT.fields_by_name['context'].message_type = brick__pb2._TRIPLE
_THERMOSTAT.fields_by_name['temperature'].message_type = nullabletypes__pb2._DOUBLE
_THERMOSTAT.fields_by_name['relative_humidity'].message_type = nullabletypes__pb2._DOUBLE
_THERMOSTAT.fields_by_name['override'].message_type = nullabletypes__pb2._BOOL
_THERMOSTAT.fields_by_name['fan_state'].message_type = nullabletypes__pb2._BOOL
_THERMOSTAT.fields_by_name['fan_mode'].message_type = nullabletypes__pb2._FANMODE
_THERMOSTAT.fields_by_name['mode'].message_type = nullabletypes__pb2._HVACMODE
_THERMOSTAT.fields_by_name['state'].message_type = nullabletypes__pb2._HVACSTATE
_THERMOSTAT.fields_by_name['enabled_heat_stages'].message_type = nullabletypes__pb2._INT32
_THERMOSTAT.fields_by_name['enabled_cool_stages'].message_type = nullabletypes__pb2._INT32
_THERMOSTAT.fields_by_name['heating_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_THERMOSTAT.fields_by_name['cooling_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_THERMOSTATSCHEDULE_SCHEDULEMAPENTRY.fields_by_name['value'].message_type = _THERMOSTATSCHEDULEDAY
_THERMOSTATSCHEDULE_SCHEDULEMAPENTRY.containing_type = _THERMOSTATSCHEDULE
_THERMOSTATSCHEDULE.fields_by_name['scheduleMap'].message_type = _THERMOSTATSCHEDULE_SCHEDULEMAPENTRY
_THERMOSTATSCHEDULEDAY.fields_by_name['blocks'].message_type = _THERMOSTATSCHEDULEBLOCK
_THERMOSTATSCHEDULEBLOCK.fields_by_name['heating_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_THERMOSTATSCHEDULEBLOCK.fields_by_name['cooling_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_THERMOSTATSCHEDULEBLOCK.fields_by_name['mode'].message_type = nullabletypes__pb2._HVACMODE
_DEMANDRESPONSEEVENT.fields_by_name['event_end'].message_type = nullabletypes__pb2._INT64
_DEMANDRESPONSEEVENT.fields_by_name['event_start'].message_type = nullabletypes__pb2._INT64
_DEMANDRESPONSEEVENT.fields_by_name['event_type'].enum_type = _DEMANDRESPONSEEVENTTYPE
_DEMANDRESPONSEEVENT.fields_by_name['dr_status'].enum_type = _DEMANDRESPONSEEVENTSTATUS
_DEMANDRESPONSEEVENT.fields_by_name['time'].message_type = nullabletypes__pb2._INT64
_METER.fields_by_name['power'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['voltage'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['apparent_power'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['energy'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['reactive_power'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['current'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['demand'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['water_total'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['water_rate'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['water_instantaneous'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['condense_total'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['condense_rate'].message_type = nullabletypes__pb2._DOUBLE
_METER.fields_by_name['condense_instantaneous'].message_type = nullabletypes__pb2._DOUBLE
_LIGHT.fields_by_name['state'].message_type = nullabletypes__pb2._BOOL
_LIGHT.fields_by_name['brightness'].message_type = nullabletypes__pb2._INT64
_EVSE.fields_by_name['current_limit'].message_type = nullabletypes__pb2._DOUBLE
_EVSE.fields_by_name['current'].message_type = nullabletypes__pb2._DOUBLE
_EVSE.fields_by_name['voltage'].message_type = nullabletypes__pb2._DOUBLE
_EVSE.fields_by_name['charging_time_left'].message_type = nullabletypes__pb2._INT32
_EVSE.fields_by_name['state'].message_type = nullabletypes__pb2._BOOL
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['XBOSIoTDeviceState'] = _XBOSIOTDEVICESTATE
DESCRIPTOR.message_types_by_name['XBOSIoTDeviceActuation'] = _XBOSIOTDEVICEACTUATION
DESCRIPTOR.message_types_by_name['XBOSIoTContext'] = _XBOSIOTCONTEXT
DESCRIPTOR.message_types_by_name['Thermostat'] = _THERMOSTAT
DESCRIPTOR.message_types_by_name['ThermostatSchedule'] = _THERMOSTATSCHEDULE
DESCRIPTOR.message_types_by_name['ThermostatScheduleDay'] = _THERMOSTATSCHEDULEDAY
DESCRIPTOR.message_types_by_name['ThermostatScheduleBlock'] = _THERMOSTATSCHEDULEBLOCK
DESCRIPTOR.message_types_by_name['DemandResponseEvent'] = _DEMANDRESPONSEEVENT
DESCRIPTOR.message_types_by_name['Meter'] = _METER
DESCRIPTOR.message_types_by_name['Light'] = _LIGHT
DESCRIPTOR.message_types_by_name['EVSE'] = _EVSE
DESCRIPTOR.enum_types_by_name['DemandResponseEventStatus'] = _DEMANDRESPONSEEVENTSTATUS
DESCRIPTOR.enum_types_by_name['DemandResponseEventType'] = _DEMANDRESPONSEEVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Error)
  ))
_sym_db.RegisterMessage(Error)

XBOSIoTDeviceState = _reflection.GeneratedProtocolMessageType('XBOSIoTDeviceState', (_message.Message,), dict(
  DESCRIPTOR = _XBOSIOTDEVICESTATE,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.XBOSIoTDeviceState)
  ))
_sym_db.RegisterMessage(XBOSIoTDeviceState)

XBOSIoTDeviceActuation = _reflection.GeneratedProtocolMessageType('XBOSIoTDeviceActuation', (_message.Message,), dict(
  DESCRIPTOR = _XBOSIOTDEVICEACTUATION,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.XBOSIoTDeviceActuation)
  ))
_sym_db.RegisterMessage(XBOSIoTDeviceActuation)

XBOSIoTContext = _reflection.GeneratedProtocolMessageType('XBOSIoTContext', (_message.Message,), dict(
  DESCRIPTOR = _XBOSIOTCONTEXT,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.XBOSIoTContext)
  ))
_sym_db.RegisterMessage(XBOSIoTContext)

Thermostat = _reflection.GeneratedProtocolMessageType('Thermostat', (_message.Message,), dict(
  DESCRIPTOR = _THERMOSTAT,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Thermostat)
  ))
_sym_db.RegisterMessage(Thermostat)

ThermostatSchedule = _reflection.GeneratedProtocolMessageType('ThermostatSchedule', (_message.Message,), dict(

  ScheduleMapEntry = _reflection.GeneratedProtocolMessageType('ScheduleMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _THERMOSTATSCHEDULE_SCHEDULEMAPENTRY,
    __module__ = 'iot_pb2'
    # @@protoc_insertion_point(class_scope:xbospb.ThermostatSchedule.ScheduleMapEntry)
    ))
  ,
  DESCRIPTOR = _THERMOSTATSCHEDULE,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.ThermostatSchedule)
  ))
_sym_db.RegisterMessage(ThermostatSchedule)
_sym_db.RegisterMessage(ThermostatSchedule.ScheduleMapEntry)

ThermostatScheduleDay = _reflection.GeneratedProtocolMessageType('ThermostatScheduleDay', (_message.Message,), dict(
  DESCRIPTOR = _THERMOSTATSCHEDULEDAY,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.ThermostatScheduleDay)
  ))
_sym_db.RegisterMessage(ThermostatScheduleDay)

ThermostatScheduleBlock = _reflection.GeneratedProtocolMessageType('ThermostatScheduleBlock', (_message.Message,), dict(
  DESCRIPTOR = _THERMOSTATSCHEDULEBLOCK,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.ThermostatScheduleBlock)
  ))
_sym_db.RegisterMessage(ThermostatScheduleBlock)

DemandResponseEvent = _reflection.GeneratedProtocolMessageType('DemandResponseEvent', (_message.Message,), dict(
  DESCRIPTOR = _DEMANDRESPONSEEVENT,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.DemandResponseEvent)
  ))
_sym_db.RegisterMessage(DemandResponseEvent)

Meter = _reflection.GeneratedProtocolMessageType('Meter', (_message.Message,), dict(
  DESCRIPTOR = _METER,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Meter)
  ))
_sym_db.RegisterMessage(Meter)

Light = _reflection.GeneratedProtocolMessageType('Light', (_message.Message,), dict(
  DESCRIPTOR = _LIGHT,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Light)
  ))
_sym_db.RegisterMessage(Light)

EVSE = _reflection.GeneratedProtocolMessageType('EVSE', (_message.Message,), dict(
  DESCRIPTOR = _EVSE,
  __module__ = 'iot_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.EVSE)
  ))
_sym_db.RegisterMessage(EVSE)


_THERMOSTAT.fields_by_name['temperature']._options = None
_THERMOSTAT.fields_by_name['relative_humidity']._options = None
_THERMOSTAT.fields_by_name['override']._options = None
_THERMOSTAT.fields_by_name['fan_state']._options = None
_THERMOSTAT.fields_by_name['fan_mode']._options = None
_THERMOSTAT.fields_by_name['mode']._options = None
_THERMOSTAT.fields_by_name['state']._options = None
_THERMOSTAT.fields_by_name['heating_setpoint']._options = None
_THERMOSTAT.fields_by_name['cooling_setpoint']._options = None
_THERMOSTAT._options = None
_THERMOSTATSCHEDULE_SCHEDULEMAPENTRY._options = None
_METER.fields_by_name['power']._options = None
_METER.fields_by_name['voltage']._options = None
_METER.fields_by_name['apparent_power']._options = None
_METER.fields_by_name['energy']._options = None
_METER.fields_by_name['reactive_power']._options = None
_METER.fields_by_name['current']._options = None
_METER.fields_by_name['demand']._options = None
_METER.fields_by_name['water_total']._options = None
_METER.fields_by_name['water_rate']._options = None
_METER.fields_by_name['water_instantaneous']._options = None
_METER.fields_by_name['condense_total']._options = None
_METER.fields_by_name['condense_rate']._options = None
_METER.fields_by_name['condense_instantaneous']._options = None
_METER._options = None
_LIGHT.fields_by_name['state']._options = None
_LIGHT.fields_by_name['brightness']._options = None
_LIGHT._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xbos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import hamilton_pb2 as hamilton__pb2
from . import iot_pb2 as iot__pb2
from . import dentmeter_pb2 as dentmeter__pb2
from . import system_monitor_pb2 as system__monitor__pb2
from . import parker_pb2 as parker__pb2
from . import c37_pb2 as c37__pb2
from . import energise_pb2 as energise__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='xbos.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\nxbos.proto\x12\x06xbospb\x1a\x0ehamilton.proto\x1a\tiot.proto\x1a\x0f\x64\x65ntmeter.proto\x1a\x14system_monitor.proto\x1a\x0cparker.proto\x1a\tc37.proto\x1a\x0e\x65nergise.proto\"\xbe\x04\n\x04XBOS\x12*\n\x0cHamiltonData\x18\x32 \x01(\x0b\x32\x14.xbospb.HamiltonData\x12\x38\n\x13HamiltonBRLinkStats\x18\x33 \x01(\x0b\x32\x1b.xbospb.HamiltonBRLinkStats\x12\x34\n\x11HamiltonBRMessage\x18\x34 \x01(\x0b\x32\x19.xbospb.HamiltonBRMessage\x12\x36\n\x12XBOSIoTDeviceState\x18\x64 \x01(\x0b\x32\x1a.xbospb.XBOSIoTDeviceState\x12>\n\x16XBOSIoTDeviceActuation\x18\x65 \x01(\x0b\x32\x1e.xbospb.XBOSIoTDeviceActuation\x12.\n\x0eXBOSIoTContext\x18\x66 \x01(\x0b\x32\x16.xbospb.XBOSIoTContext\x12/\n\x0e\x44\x65ntMeterState\x18\x96\x01 \x01(\x0b\x32\x16.xbospb.DentMeterState\x12*\n\x0cparker_state\x18\x97\x01 \x01(\x0b\x32\x13.xbospb.ParkerState\x12\x35\n\x11\x42\x61sicServerStatus\x18\xc8\x01 \x01(\x0b\x32\x19.xbospb.BasicServerStatus\x12+\n\x0c\x43\x33\x37\x44\x61taFrame\x18\xfa\x01 \x01(\x0b\x32\x14.xbospb.C37DataFrame\x12\x31\n\x0f\x45nergiseMessage\x18\xfb\x01 \x01(\x0b\x32\x17.xbospb.EnergiseMessage\"x\n\x08Resource\x12$\n\ttransport\x18\x01 \x01(\x0e\x32\x11.xbospb.Transport\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t*!\n\tTransport\x12\n\n\x06WAVEMQ\x10\x00\x12\x08\n\x04GRPC\x10\x01\x62\x06proto3')
  ,
  dependencies=[hamilton__pb2.DESCRIPTOR,iot__pb2.DESCRIPTOR,dentmeter__pb2.DESCRIPTOR,system__monitor__pb2.DESCRIPTOR,parker__pb2.DESCRIPTOR,c37__pb2.DESCRIPTOR,energise__pb2.DESCRIPTOR,])

_TRANSPORT = _descriptor.EnumDescriptor(
  name='Transport',
  full_name='xbospb.Transport',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WAVEMQ', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GRPC', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=828,
  serialized_end=861,
)
_sym_db.RegisterEnumDescriptor(_TRANSPORT)

Transport = enum_type_wrapper.EnumTypeWrapper(_TRANSPORT)
WAVEMQ = 0
GRPC = 1



_XBOS = _descriptor.Descriptor(
  name='XBOS',
  full_name='xbospb.XBOS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='HamiltonData', full_name='xbospb.XBOS.HamiltonData', index=0,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='HamiltonBRLinkStats', full_name='xbospb.XBOS.HamiltonBRLinkStats', index=1,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='HamiltonBRMessage', full_name='xbospb.XBOS.HamiltonBRMessage', index=2,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='XBOSIoTDeviceState', full_name='xbospb.XBOS.XBOSIoTDeviceState', index=3,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='XBOSIoTDeviceActuation', full_name='xbospb.XBOS.XBOSIoTDeviceActuation', index=4,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='XBOSIoTContext', full_name='xbospb.XBOS.XBOSIoTContext', index=5,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='DentMeterState', full_name='xbospb.XBOS.DentMeterState', index=6,
      number=150, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parker_state', full_name='xbospb.XBOS.parker_state', index=7,
      number=151, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='BasicServerStatus', full_name='xbospb.XBOS.BasicServerStatus', index=8,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='C37DataFrame', full_name='xbospb.XBOS.C37DataFrame', index=9,
      number=250, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='EnergiseMessage', full_name='xbospb.XBOS.EnergiseMessage', index=10,
      number=251, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=704,
)


_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='xbospb.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transport', full_name='xbospb.Resource.transport', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='xbospb.Resource.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='xbospb.Resource.service', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='xbospb.Resource.instance', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='xbospb.Resource.location', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=706,
  serialized_end=826,
)

_XBOS.fields_by_name['HamiltonData'].message_type = hamilton__pb2._HAMILTONDATA
_XBOS.fields_by_name['HamiltonBRLinkStats'].message_type = hamilton__pb2._HAMILTONBRLINKSTATS
_XBOS.fields_by_name['HamiltonBRMessage'].message_type = hamilton__pb2._HAMILTONBRMESSAGE
_XBOS.fields_by_name['XBOSIoTDeviceState'].message_type = iot__pb2._XBOSIOTDEVICESTATE
_XBOS.fields_by_name['XBOSIoTDeviceActuation'].message_type = iot__pb2._XBOSIOTDEVICEACTUATION
_XBOS.fields_by_name['XBOSIoTContext'].message_type = iot__pb2._XBOSIOTCONTEXT
_XBOS.fields_by_name['DentMeterState'].message_type = dentmeter__pb2._DENTMETERSTATE
_XBOS.fields_by_name['parker_state'].message_type = parker__pb2._PARKERSTATE
_XBOS.fields_by_name['BasicServerStatus'].message_type = system__monitor__pb2._BASICSERVERSTATUS
_XBOS.fields_by_name['C37DataFrame'].message_type = c37__pb2._C37DATAFRAME
_XBOS.fields_by_name['EnergiseMessage'].message_type = energise__pb2._ENERGISEMESSAGE
_RESOURCE.fields_by_name['transport'].enum_type = _TRANSPORT
DESCRIPTOR.message_types_by_name['XBOS'] = _XBOS
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
DESCRIPTOR.enum_types_by_name['Transport'] = _TRANSPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

XBOS = _reflection.GeneratedProtocolMessageType('XBOS', (_message.Message,), dict(
  DESCRIPTOR = _XBOS,
  __module__ = 'xbos_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.XBOS)
  ))
_sym_db.RegisterMessage(XBOS)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), dict(
  DESCRIPTOR = _RESOURCE,
  __module__ = 'xbos_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Resource)
  ))
_sym_db.RegisterMessage(Resource)


# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import eapi_pb2 as eapi__pb2


class WAVEStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateEntity = channel.unary_unary(
        '/mqpb.WAVE/CreateEntity',
        request_serializer=eapi__pb2.CreateEntityParams.SerializeToString,
        response_deserializer=eapi__pb2.CreateEntityResponse.FromString,
        )
    self.CreateAttestation = channel.unary_unary(
        '/mqpb.WAVE/CreateAttestation',
        request_serializer=eapi__pb2.CreateAttestationParams.SerializeToString,
        response_deserializer=eapi__pb2.CreateAttestationResponse.FromString,
        )
    self.PublishEntity = channel.unary_unary(
        '/mqpb.WAVE/PublishEntity',
        request_serializer=eapi__pb2.PublishEntityParams.SerializeToString,
        response_deserializer=eapi__pb2.PublishEntityResponse.FromString,
        )
    self.PublishAttestation = channel.unary_unary(
        '/mqpb.WAVE/PublishAttestation',
        request_serializer=eapi__pb2.PublishAttestationParams.SerializeToString,
        response_deserializer=eapi__pb2.PublishAttestationResponse.FromString,
        )
    self.AddAttestation = channel.unary_unary(
        '/mqpb.WAVE/AddAttestation',
        request_serializer=eapi__pb2.AddAttestationParams.SerializeToString,
        response_deserializer=eapi__pb2.AddAttestationResponse.FromString,
        )
    self.LookupAttestations = channel.unary_unary(
        '/mqpb.WAVE/LookupAttestations',
        request_serializer=eapi__pb2.LookupAttestationsParams.SerializeToString,
        response_deserializer=eapi__pb2.LookupAttestationsResponse.FromString,
        )
    self.ResyncPerspectiveGraph = channel.unary_unary(
        '/mqpb.WAVE/ResyncPerspectiveGraph',
        request_serializer=eapi__pb2.ResyncPerspectiveGraphParams.SerializeToString,
        response_deserializer=eapi__pb2.ResyncPerspectiveGraphResponse.FromString,
        )
    self.SyncStatus = channel.unary_unary(
        '/mqpb.WAVE/SyncStatus',
        request_serializer=eapi__pb2.SyncParams.SerializeToString,
        response_deserializer=eapi__pb2.SyncResponse.FromString,
        )
    self.WaitForSyncComplete = channel.unary_stream(
        '/mqpb.WAVE/WaitForSyncComplete',
        request_serializer=eapi__pb2.SyncParams.SerializeToString,
        response_deserializer=eapi__pb2.SyncResponse.FromString,
        )
    self.BuildRTreeProof = channel.unary_unary(
        '/mqpb.WAVE/BuildRTreeProof',
        request_serializer=eapi__pb2.BuildRTreeProofParams.SerializeToString,
        response_deserializer=eapi__pb2.BuildRTreeProofResponse.FromString,
        )
    self.VerifyProof = channel.unary_unary(
        '/mqpb.WAVE/VerifyProof',
        request_serializer=eapi__pb2.VerifyProofParams.SerializeToString,
        response_deserializer=eapi__pb2.VerifyProofResponse.FromString,
        )
    self.ListLocations = channel.unary_unary(
        '/mqpb.WAVE/ListLocations',
        request_serializer=eapi__pb2.ListLocationsParams.SerializeToString,
        response_deserializer=eapi__pb2.ListLocationsResponse.FromString,
        )
    self.Inspect = channel.unary_unary(
        '/mqpb.WAVE/Inspect',
        request_serializer=eapi__pb2.InspectParams.SerializeToString,
        response_deserializer=eapi__pb2.InspectResponse.FromString,
        )
    self.ResolveHash = channel.unary_unary(
        '/mqpb.WAVE/ResolveHash',
        request_serializer=eapi__pb2.ResolveHashParams.SerializeToString,
        response_deserializer=eapi__pb2.ResolveHashResponse.FromString,
        )
    self.EncryptMessage = channel.unary_unary(
        '/mqpb.WAVE/EncryptMessage',
        request_serializer=eapi__pb2.EncryptMessageParams.SerializeToString,
        response_deserializer=eapi__pb2.EncryptMessageResponse.FromString,
        )
    self.DecryptMessage = channel.unary_unary(
        '/mqpb.WAVE/DecryptMessage',
        request_serializer=eapi__pb2.DecryptMessageParams.SerializeToString,
        response_deserializer=eapi__pb2.DecryptMessageResponse.FromString,
        )
    self.CreateNameDeclaration = channel.unary_unary(
        '/mqpb.WAVE/CreateNameDeclaration',
        request_serializer=eapi__pb2.CreateNameDeclarationParams.SerializeToString,
        response_deserializer=eapi__pb2.CreateNameDeclarationResponse.FromString,
        )
    self.ResolveName = channel.unary_unary(
        '/mqpb.WAVE/ResolveName',
        request_serializer=eapi__pb2.ResolveNameParams.SerializeToString,
        response_deserializer=eapi__pb2.ResolveNameResponse.FromString,
        )
    self.MarkEntityInteresting = channel.unary_unary(
        '/mqpb.WAVE/MarkEntityInteresting',
        request_serializer=eapi__pb2.MarkEntityInterestingParams.SerializeToString,
        response_deserializer=eapi__pb2.MarkEntityInterestingResponse.FromString,
        )
    self.ResolveReverseName = channel.unary_unary(
        '/mqpb.WAVE/ResolveReverseName',
        request_serializer=eapi__pb2.ResolveReverseNameParams.SerializeToString,
        response_deserializer=eapi__pb2.ResolveReverseNameResponse.FromString,
        )
    self.Revoke = channel.unary_unary(
        '/mqpb.WAVE/Revoke',
        request_serializer=eapi__pb2.RevokeParams.SerializeToString,
        response_deserializer=eapi__pb2.RevokeResponse.FromString,
        )
    self.CompactProof = channel.unary_unary(
        '/mqpb.WAVE/CompactProof',
        request_serializer=eapi__pb2.CompactProofParams.SerializeToString,
        response_deserializer=eapi__pb2.CompactProofResponse.FromString,
        )


class WAVEServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateEntity(self, request, context):
    """Create a new WAVE entity, but do not publish it
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateAttestation(self, request, context):
    """Create a WAVE attestation, both the source and destination entities must
    be published
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PublishEntity(self, request, context):
    """Publish the given entity
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PublishAttestation(self, request, context):
    """Publish an attestation
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddAttestation(self, request, context):
    """Add an attestation to the given perspective graph
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LookupAttestations(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResyncPerspectiveGraph(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SyncStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WaitForSyncComplete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BuildRTreeProof(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def VerifyProof(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListLocations(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Inspect(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResolveHash(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EncryptMessage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DecryptMessage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateNameDeclaration(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResolveName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarkEntityInteresting(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResolveReverseName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Revoke(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CompactProof(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_WAVEServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateEntity': grpc.unary_unary_rpc_method_handler(
          servicer.CreateEntity,
          request_deserializer=eapi__pb2.CreateEntityParams.FromString,
          response_serializer=eapi__pb2.CreateEntityResponse.SerializeToString,
      ),
      'CreateAttestation': grpc.unary_unary_rpc_method_handler(
          servicer.CreateAttestation,
          request_deserializer=eapi__pb2.CreateAttestationParams.FromString,
          response_serializer=eapi__pb2.CreateAttestationResponse.SerializeToString,
      ),
      'PublishEntity': grpc.unary_unary_rpc_method_handler(
          servicer.PublishEntity,
          request_deserializer=eapi__pb2.PublishEntityParams.FromString,
          response_serializer=eapi__pb2.PublishEntityResponse.SerializeToString,
      ),
      'PublishAttestation': grpc.unary_unary_rpc_method_handler(
          servicer.PublishAttestation,
          request_deserializer=eapi__pb2.PublishAttestationParams.FromString,
          response_serializer=eapi__pb2.PublishAttestationResponse.SerializeToString,
      ),
      'AddAttestation': grpc.unary_unary_rpc_method_handler(
          servicer.AddAttestation,
          request_deserializer=eapi__pb2.AddAttestationParams.FromString,
          response_serializer=eapi__pb2.AddAttestationResponse.SerializeToString,
      ),
      'LookupAttestations': grpc.unary_unary_rpc_method_handler(
          servicer.LookupAttestations,
          request_deserializer=eapi__pb2.LookupAttestationsParams.FromString,
          response_serializer=eapi__pb2.LookupAttestationsResponse.SerializeToString,
      ),
      'ResyncPerspectiveGraph': grpc.unary_unary_rpc_method_handler(
          servicer.ResyncPerspectiveGraph,
          request_deserializer=eapi__pb2.ResyncPerspectiveGraphParams.FromString,
          response_serializer=eapi__pb2.ResyncPerspectiveGraphResponse.SerializeToString,
      ),
      'SyncStatus': grpc.unary_unary_rpc_method_handler(
          servicer.SyncStatus,
          request_deserializer=eapi__pb2.SyncParams.FromString,
          response_serializer=eapi__pb2.SyncResponse.SerializeToString,
      ),
      'WaitForSyncComplete': grpc.unary_stream_rpc_method_handler(
          servicer.WaitForSyncComplete,
          request_deserializer=eapi__pb2.SyncParams.FromString,
          response_serializer=eapi__pb2.SyncResponse.SerializeToString,
      ),
      'BuildRTreeProof': grpc.unary_unary_rpc_method_handler(
          servicer.BuildRTreeProof,
          request_deserializer=eapi__pb2.BuildRTreeProofParams.FromString,
          response_serializer=eapi__pb2.BuildRTreeProofResponse.SerializeToString,
      ),
      'VerifyProof': grpc.unary_unary_rpc_method_handler(
          servicer.VerifyProof,
          request_deserializer=eapi__pb2.VerifyProofParams.FromString,
          response_serializer=eapi__pb2.VerifyProofResponse.SerializeToString,
      ),
      'ListLocations': grpc.unary_unary_rpc_method_handler(
          servicer.ListLocations,
          request_deserializer=eapi__pb2.ListLocationsParams.FromString,
          response_serializer=eapi__pb2.ListLocationsResponse.SerializeToString,
      ),
      'Inspect': grpc.unary_unary_rpc_method_handler(
          servicer.Inspect,
          request_deserializer=eapi__pb2.InspectParams.FromString,
          response_serializer=eapi__pb2.InspectResponse.SerializeToString,
      ),
      'ResolveHash': grpc.unary_unary_rpc_method_handler(
          servicer.ResolveHash,
          request_deserializer=eapi__pb2.ResolveHashParams.FromString,
          response_serializer=eapi__pb2.ResolveHashResponse.SerializeToString,
      ),
      'EncryptMessage': grpc.unary_unary_rpc_method_handler(
          servicer.EncryptMessage,
          request_deserializer=eapi__pb2.EncryptMessageParams.FromString,
          response_serializer=eapi__pb2.EncryptMessageResponse.SerializeToString,
      ),
      'DecryptMessage': grpc.unary_unary_rpc_method_handler(
          servicer.DecryptMessage,
          request_deserializer=eapi__pb2.DecryptMessageParams.FromString,
          response_serializer=eapi__pb2.DecryptMessageResponse.SerializeToString,
      ),
      'CreateNameDeclaration': grpc.unary_unary_rpc_method_handler(
          servicer.CreateNameDeclaration,
          request_deserializer=eapi__pb2.CreateNameDeclarationParams.FromString,
          response_serializer=eapi__pb2.CreateNameDeclarationResponse.SerializeToString,
      ),
      'ResolveName': grpc.unary_unary_rpc_method_handler(
          servicer.ResolveName,
          request_deserializer=eapi__pb2.ResolveNameParams.FromString,
          response_serializer=eapi__pb2.ResolveNameResponse.SerializeToString,
      ),
      'MarkEntityInteresting': grpc.unary_unary_rpc_method_handler(
          servicer.MarkEntityInteresting,
          request_deserializer=eapi__pb2.MarkEntityInterestingParams.FromString,
          response_serializer=eapi__pb2.MarkEntityInterestingResponse.SerializeToString,
      ),
      'ResolveReverseName': grpc.unary_unary_rpc_method_handler(
          servicer.ResolveReverseName,
          request_deserializer=eapi__pb2.ResolveReverseNameParams.FromString,
          response_serializer=eapi__pb2.ResolveReverseNameResponse.SerializeToString,
      ),
      'Revoke': grpc.unary_unary_rpc_method_handler(
          servicer.Revoke,
          request_deserializer=eapi__pb2.RevokeParams.FromString,
          response_serializer=eapi__pb2.RevokeResponse.SerializeToString,
      ),
      'CompactProof': grpc.unary_unary_rpc_method_handler(
          servicer.CompactProof,
          request_deserializer=eapi__pb2.CompactProofParams.FromString,
          response_serializer=eapi__pb2.CompactProofResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'mqpb.WAVE', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



WaveBuiltinPSET = b"\x1b\x20\x19\x49\x54\xe8\x6e\xeb\x8f\x91\xff\x98\x3a\xcc\x56\xe6\xc8\x4a\xe2\x9a\x90\x7c\xe7\xe7\x63\x8e\x86\x57\xd5\x14\x99\xb1\x88\xa4"
WaveGlobalNamespace = b"\x1b\x20\xcf\x8d\x19\xd7\x9d\x23\x01\x38\x65\xbe\xf7\x57\xce\xa0\x4c\xde\xe5\xef\x4e\xde\xfc\x80\x8d\xd2\x1e\x4e\x00\x5e\x6f\x80\x47\xcc"

WaveBuiltinE2EE = "decrypt"
